@@ -3,7 +3,7 @@
 {-# LANGUAGE GADTs                     #-}
 {-# LANGUAGE UnicodeSyntax             #-}
 {-
-    Copyright  : Copyright (C) 2014-2020 Synchrotron SOLEIL
+    Copyright  : Copyright (C) 2014-2021 Synchrotron SOLEIL
                                          L'Orme des Merisiers Saint-Aubin
                                          BP 48 91192 GIF-sur-YVETTE CEDEX
     License    : GPL3+
@@ -20,22 +20,25 @@ module Hkl.H5
     , check_ndims
     , closeDataset
     , closeFile
+    , getArrayInBuffer
     , get_image
     , get_image'
     , get_position
     , get_position_new
     , get_ub
     , lenH5Dataspace
+    , datasetShape
     , nxEntries
     , nxEntries'
     , openDataset
+    , openDatasetWithAttr
     , openH5
     , set_image
     , withH5File
     -- new API
     , Hdf5
     , ToHdf5(..)
-    , empty
+    , Hkl.H5.empty
     , hdf5
     , group
     , dataset
@@ -45,11 +48,16 @@ module Hkl.H5
     , groupp
     , grouppat
     , datasetp
+    , datasetpattr
     , withHdf5Path'
     , withHdf5Path
     )
     where
 
+import           Bindings.HDF5.Attribute         (Attribute, closeAttribute,
+                                                  doesAttributeExist,
+                                                  openAttribute,
+                                                  readAttributeStringASCII)
 import           Bindings.HDF5.Core              (HSize (HSize),
                                                   IndexType (ByName),
                                                   IterOrder (Native), Location,
@@ -64,6 +72,7 @@ import           Bindings.HDF5.Dataspace         (Dataspace,
                                                   SelectionOperator (Set),
                                                   closeDataspace,
                                                   createSimpleDataspace,
+                                                  getSimpleDataspaceExtent,
                                                   getSimpleDataspaceExtentNDims,
                                                   getSimpleDataspaceExtentNPoints,
                                                   selectHyperslab, selectNone)
@@ -75,12 +84,17 @@ import           Bindings.HDF5.File              (AccFlags (ReadOnly, Truncate),
                                                   openFile)
 import           Bindings.HDF5.Group             (Group, closeGroup,
                                                   createGroup, openGroup)
+import           Bindings.HDF5.Link              (visitLinks)
+import           Bindings.HDF5.Object            (ObjectId, ObjectType (..),
+                                                  closeObject, getObjectType,
+                                                  openObject)
 import           Bindings.HDF5.PropertyList.DXPL (DXPL)
 import           Bindings.HDF5.Raw               (H5L_info_t, HErr_t (HErr_t),
                                                   HId_t (HId_t), h5d_read,
                                                   h5l_iterate, h5p_DEFAULT,
                                                   h5s_ALL)
-import           Control.Exception               (bracket)
+import           Control.Exception               (Exception, bracket, throwIO)
+import           Control.Monad.Extra             (fromMaybeM)
 import           Data.Array.Repa                 (Array, Shape, extent,
                                                   linearIndex, listOfShape,
                                                   size)
@@ -91,12 +105,13 @@ import           Data.ByteString.Char8           (ByteString, pack, packCString,
 import           Data.IORef                      (modifyIORef', newIORef,
                                                   readIORef)
 import           Data.Vector.Storable            (Storable, Vector, freeze,
-                                                  unsafeFromForeignPtr0)
-import           Data.Vector.Storable.Mutable    (MVector (..), replicate)
+                                                  head, unsafeFromForeignPtr0)
+import           Data.Vector.Storable.Mutable    (MVector (..), new, replicate)
 import           Data.Word                       (Word16)
 import           Foreign.C.String                (CString)
 import           Foreign.C.Types                 (CInt (CInt))
-import           Foreign.ForeignPtr              (ForeignPtr, newForeignPtr)
+import           Foreign.ForeignPtr              (ForeignPtr, newForeignPtr,
+                                                  withForeignPtr)
 import           Foreign.Marshal.Alloc           (finalizerFree, mallocBytes)
 import           Foreign.Ptr                     (FunPtr, Ptr,
                                                   freeHaskellFunPtr)
@@ -107,12 +122,20 @@ import           Foreign.StablePtr               (StablePtr, castPtrToStablePtr,
                                                   castStablePtrToPtr,
                                                   deRefStablePtr, freeStablePtr,
                                                   newStablePtr)
+import           GHC.Base                        (Alternative (..))
 import           Numeric.LinearAlgebra           (Matrix, reshape)
 
 import           Hkl.Detector
 
+import           Prelude                         hiding (head)
+
 {-# ANN module "HLint: ignore Use camelCase" #-}
 
+data HklH5Exception
+  = CanNotFindDatasetWithAttributContent ByteString ByteString
+  deriving (Show)
+
+instance Exception HklH5Exception
 
 data H5
 
@@ -156,6 +179,16 @@ get_image' det d n = withDataspace (getDatasetSpace d) $ \dataspace -> do
         readDatasetInto' d (Just memspace) (Just dataspace) Nothing p
         newForeignPtr finalizerFree p
 
+getArrayInBuffer :: Shape sh => ForeignPtr Word16 -> Detector a sh -> Dataset -> Int -> IO (ForeignPtr Word16)
+getArrayInBuffer fbuf det d n = withDataspace (getDatasetSpace d) $ \dataspace -> do
+      let s = shape det
+          h = (HSize (fromIntegral n), Nothing,  HSize 1, Nothing) : shapeAsRangeToHyperslab s
+      selectHyperslab dataspace Set h
+      withDataspace (createDataspaceFromShape s) $ \memspace ->
+          withForeignPtr fbuf $ \buf -> do
+            _ <- readDatasetInto' d (Just memspace) (Just dataspace) Nothing buf
+            return fbuf
+
 set_image :: Shape sh => Detector a sh -> Dataset -> Dataspace -> Int -> Array F sh Word16 -> IO ()
 set_image det d dataspace n arr =  do
   selectNone dataspace
@@ -172,27 +205,29 @@ saveRepa f path arr =
   withDataset (createDataset f path (nativeTypeOf (linearIndex arr 0)) dataspace Nothing Nothing Nothing) $ \dataset' ->
   writeDataset dataset' Nothing Nothing Nothing (castToVector arr)
 
-getPosition' :: Dataset -> [(HSize, Maybe HSize, HSize, Maybe HSize)] -> IO (Vector Double)
+getPosition' :: NativeType t => Dataset -> [(HSize, Maybe HSize, HSize, Maybe HSize)] -> IO (Vector t)
 getPosition' dataset' h =
     withDataspace (getDatasetSpace dataset') $ \dataspace -> do
       selectHyperslab dataspace Set h
       withDataspace (createSimpleDataspace [HSize 1]) $ \memspace -> do
-        data_out <- Data.Vector.Storable.Mutable.replicate 1 (0.0 :: Double)
+        data_out <- Data.Vector.Storable.Mutable.new 1
         readDatasetInto dataset' (Just memspace) (Just dataspace) Nothing data_out
         freeze data_out
 
 get_position_new :: Shape sh => Dataset -> sh -> IO (Vector Double)
 get_position_new dataset' s = getPosition' dataset' (shapeAsCoordinateToHyperslab s)
 
-get_position :: Dataset -> Int -> IO (Vector Double)
-get_position dataset' n = getPosition' dataset' [(HSize (fromIntegral n), Nothing,  HSize 1, Nothing)]
+get_position :: NativeType t => Dataset -> Int -> IO t
+get_position dataset' n = do
+  v <- getPosition' dataset' [(HSize (fromIntegral n), Nothing,  HSize 1, Nothing)]
+  return $ head v
 
 get_ub :: Dataset -> IO (Matrix Double)
 get_ub dataset' = do
   v <- readDataset dataset' Nothing Nothing
   return $ reshape 3 v
 
--- | File
+--  File
 
 withH5File' :: IO File -> (File -> IO r) -> IO r
 withH5File' a = bracket a closeFile
@@ -203,7 +238,7 @@ withH5File fp = withH5File' (openFile (pack fp) [ReadOnly] Nothing)
 openH5 ∷ FilePath → IO File
 openH5 f = openFile (pack f) [ReadOnly] Nothing
 
--- | Group
+--  Group
 
 withGroup :: IO Group -> (Group -> IO r) -> IO r
 withGroup a = bracket a closeGroup
@@ -213,7 +248,7 @@ withGroupAt l i f = do
   es <- nxEntries' l
   withGroup (openGroup l (es !! i) Nothing) f
 
--- | Dataspace
+--  Dataspace
 
 -- check how to merge both methods
 
@@ -227,7 +262,10 @@ lenH5Dataspace d = withDataspace (getDatasetSpace d) len
       (HSize n) <- getSimpleDataspaceExtentNPoints space_id
       return $ if n < 0 then Nothing else Just (fromIntegral n)
 
--- | DataSet
+datasetShape :: Dataset -> IO ([HSize], [Maybe HSize])
+datasetShape d = withDataspace (getDatasetSpace d) getSimpleDataspaceExtent
+
+--  DataSet
 
 withDataset :: IO Dataset -> (Dataset -> IO r) -> IO r
 withDataset a = bracket a closeDataset
@@ -242,7 +280,7 @@ readDatasetInto' :: NativeType t =>
 readDatasetInto' dset mem_space_id file_space_id plist_id buf =
     withErrorCheck_ $ h5d_read (hid dset) (hdfTypeOf1 buf) (maybe h5s_ALL hid mem_space_id) (maybe h5s_ALL hid file_space_id) (maybe h5p_DEFAULT hid plist_id) (OutArray buf)
 
--- | WIP until I have decided what is the right way to go
+--  WIP until I have decided what is the right way to go
 
 type H5Iterate a = HId_t -> CString -> In H5L_info_t -> InOut a -> IO HErr_t
 
@@ -281,7 +319,37 @@ nxEntries' l = do
         modifyIORef' stRef $ \st -> name : st
         return $ HErr_t 0
 
--- | Better API
+-- Attribute
+
+withObject :: IO ObjectId -> (ObjectId -> IO r) -> IO r
+withObject a = bracket a closeObject
+
+withAttribute :: IO Attribute -> (Attribute -> IO r) -> IO r
+withAttribute a = bracket a closeAttribute
+
+openDatasetWithAttr :: Location l => l -> ByteString -> ByteString -> IO Dataset
+openDatasetWithAttr loc attr value = do
+  state <- newIORef (Nothing :: Maybe Dataset)
+  visitLinks loc ByName Native $ \g n _ -> do
+    withObject (openObject g n Nothing) $ \obj -> do
+      t <-  getObjectType obj
+      case t of
+        DatasetObj -> do
+          exist <- doesAttributeExist obj attr
+          case exist of
+            True -> withAttribute (openAttribute obj attr) $ \a -> do
+              c <- readAttributeStringASCII a
+              case c == value of
+                True -> do
+                  ds <- openDataset g n Nothing
+                  modifyIORef' state $ \_ -> (Just ds)
+                  return $ HErr_t 1
+                False -> return $ HErr_t 0
+            False -> return $ HErr_t 0
+        _          -> return $ HErr_t 0
+  fromMaybeM (throwIO $ CanNotFindDatasetWithAttributContent attr value) (readIORef state)
+
+--  Better API
 
 data Hdf5M a
   = H5Empty
@@ -322,6 +390,9 @@ data Hdf5Path sh e
   | H5GroupPath ByteString (Hdf5Path sh e)
   | H5GroupAtPath Int (Hdf5Path sh e)
   | H5DatasetPath ByteString
+  | H5DatasetPathAttr (ByteString, ByteString)
+  | H5Or (Hdf5Path sh e) (Hdf5Path sh e)
+    deriving (Show)
 
 hdf5p :: Hdf5Path sh e -> Hdf5Path sh e
 hdf5p = H5RootPath
@@ -335,11 +406,19 @@ grouppat = H5GroupAtPath
 datasetp :: ByteString -> Hdf5Path sh e
 datasetp = H5DatasetPath
 
+datasetpattr :: (ByteString, ByteString) -> Hdf5Path sh e
+datasetpattr = H5DatasetPathAttr
+
 withHdf5Path' :: Location l => l -> Hdf5Path sh e -> (Dataset -> IO r) -> IO r
-withHdf5Path' l (H5RootPath subpath) f = withHdf5Path' l subpath f
-withHdf5Path' l (H5GroupPath n subpath) f = withGroup (openGroup l n Nothing) $ \g -> withHdf5Path' g subpath f
-withHdf5Path' l (H5GroupAtPath i subpath) f = withGroupAt l i $ \g -> withHdf5Path' g subpath f
-withHdf5Path' l (H5DatasetPath n) f = withDataset (openDataset l n Nothing) f
+withHdf5Path' loc (H5RootPath subpath) f = withHdf5Path' loc subpath f
+withHdf5Path' loc (H5GroupPath n subpath) f = withGroup (openGroup loc n Nothing) $ \g -> withHdf5Path' g subpath f
+withHdf5Path' loc (H5GroupAtPath i subpath) f = withGroupAt loc i $ \g -> withHdf5Path' g subpath f
+withHdf5Path' loc (H5DatasetPath n) f = withDataset (openDataset loc n Nothing) f
+withHdf5Path' loc (H5DatasetPathAttr (a, c)) f = withDataset (openDatasetWithAttr loc a c) f
+withHdf5Path' loc (H5Or l r) f = (withHdf5Path' loc l f) <|> (withHdf5Path' loc r f)
 
 withHdf5Path :: FilePath -> Hdf5Path sh e -> (Dataset -> IO r) -> IO r
 withHdf5Path fn path f = withH5File fn $ \fn' -> withHdf5Path' fn' path f
+
+-- TODO
+-- http://book.realworldhaskell.org/read/io-case-study-a-library-for-searching-the-filesystem.html
