@@ -57,29 +57,29 @@ data XrdMesh
 data XrdZeroD
 
 data DataFrameH5Path a where
-  XrdFlatH5Path ∷ DataItem H5 -- ^ image
+  XrdFlatH5Path ∷ DataItem H5 --  image
                 → DataFrameH5Path XrdFlat
-  XrdOneDH5Path ∷ DataItem H5 -- ^ image
-                → DataItem H5 -- ^ gamma
-                → DataItem H5 -- ^ delta
-                → DataItem H5 -- ^ wavelength
+  XrdOneDH5Path ∷ DataItem H5 --  image
+                → DataItem H5 --  gamma
+                → DataItem H5 --  delta
+                → DataItem H5 --  wavelength
                 → DataFrameH5Path XrdOneD
-  XrdMeshH5Path ∷ DataItem H5 -- ^ Image
-                → DataItem H5 -- ^ meshx
-                → DataItem H5 -- ^ meshy
-                → DataItem H5 -- ^ gamma
-                → DataItem H5 -- ^ delta
-                → DataItem H5 -- ^ wavelength
+  XrdMeshH5Path ∷ DataItem H5 --  Image
+                → DataItem H5 --  meshx
+                → DataItem H5 --  meshy
+                → DataItem H5 --  gamma
+                → DataItem H5 --  delta
+                → DataItem H5 --  wavelength
                 → DataFrameH5Path XrdMesh
-  XrdMeshFlyH5Path ∷ DataItem H5 -- ^ Image
-                   → DataItem H5 -- ^ meshx
-                   → DataItem H5 -- ^ meshy
-                   → DataItem Double -- ^ gamma
-                   → DataItem Double -- ^ delta
-                   → DataItem Double -- ^ wavelength
+  XrdMeshFlyH5Path ∷ DataItem H5 --  Image
+                   → DataItem H5 --  meshx
+                   → DataItem H5 --  meshy
+                   → DataItem Double --  gamma
+                   → DataItem Double --  delta
+                   → DataItem Double --  wavelength
                    → DataFrameH5Path XrdMesh
-  XrdZeroDH5Path ∷ DataItem H5 -- ^ image
-                 → DataItem Double -- ^ wavelength
+  XrdZeroDH5Path ∷ DataItem H5 --  image
+                 → DataItem Double --  wavelength
                  → DataFrameH5Path XrdZeroD -- used to integrate one static image
 
 deriving instance Show (DataFrameH5Path a)
@@ -128,7 +128,7 @@ data DataFrameH5 a where
 mkNxs ∷ FilePath → NxEntry → (NxEntry → DataFrameH5Path a) → Nxs a
 mkNxs f e h = Nxs f (h e)
 
--- | Instanciate a DataFrameH5 from a DataFrameH5Path
+--  Instanciate a DataFrameH5 from a DataFrameH5Path
 -- acquire and release the resources
 
 after ∷ DataFrameH5 a → IO ()
@@ -210,7 +210,7 @@ before nxs'@(Nxs f (XrdZeroDH5Path i w)) = do
 withDataSource :: Nxs a -> (DataFrameH5 a -> IO r) -> IO r
 withDataSource s = Control.Exception.Base.bracket (before s) after
 
--- | Pipe
+--  Pipe
 
 withDataFrameH5 :: (MonadSafe m) => Nxs XrdOneD -> PoniGenerator -> (DataFrameH5 XrdOneD -> m r) -> m r
 withDataFrameH5 nxs'@(Nxs f (XrdOneDH5Path _ g d w)) gen = Pipes.Safe.bracket (liftIO before') (liftIO . after)
