@@ -1,19 +1,20 @@
-{-# LANGUAGE CPP #-}
+{-# LANGUAGE CPP               #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 module Hkl.Projects.Diffabs.IRDRx
        ( irdrx ) where
 
-import Data.Array.Repa (DIM1, ix1)
-import Numeric.LinearAlgebra (ident)
-import System.FilePath ((</>))
-import Text.Printf (printf)
+import           Data.Array.Repa       (DIM1, ix1)
+import           Numeric.LinearAlgebra (ident)
+import           System.FilePath       ((</>))
+import           Text.Printf           (printf)
 
-import Prelude hiding (concat, lookup, readFile, writeFile)
+import           Prelude               hiding (concat, lookup, readFile,
+                                        writeFile)
 
-import Hkl
+import           Hkl
 
--- | Samples
+--  Samples
 
 project :: FilePath
 project = "/nfs/ruche-diffabs/diffabs-soleil/com-diffabs/"
@@ -45,7 +46,7 @@ h5path' nxentry =
           delta = "scan_data/data_03"
           wavelength = "D13-1-C03__OP__MONO__#1/wavelength"
 
-sampleCalibration :: XRDCalibration ImXpadS140
+sampleCalibration :: XRDCalibration PyFAI
 sampleCalibration = XRDCalibration { xrdCalibrationName = "calibration"
                                    , xrdCalibrationOutputDir = published </> "calibration" -- TODO pourquoi ce output
                                    , xrdCalibrationDetector = ImXpadS140
@@ -132,7 +133,7 @@ fly = XrdMeshSample "scan5"
       delta = -6.2 / 180.0 * 3.14159
       wavelength = 1.54 -- TODO vérifier
 
--- | Main
+--  Main
 
 irdrx :: IO ()
 irdrx = do
