@@ -1,21 +1,21 @@
 {-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE UnicodeSyntax #-}
+{-# LANGUAGE UnicodeSyntax     #-}
 
 module Hkl.Projects.Mars.Schlegel
        ( schlegel ) where
 
-import System.FilePath ((</>))
+import           System.FilePath ((</>))
 
-import Prelude hiding (concat, lookup, readFile, writeFile)
+import           Prelude         hiding (concat, lookup, readFile, writeFile)
 
-import Hkl
+import           Hkl
 
--- | TODO
--- * check if the
--- * find a way to use integrateMulti with a small amount of memory.
--- * better mask for each detector.
+--  TODO
+--  check if the
+--  find a way to use integrateMulti with a small amount of memory.
+--  better mask for each detector.
 
--- | Samples
+--  Samples
 
 project :: FilePath
 project = "/nfs/share-temp/picca/20160800"
@@ -32,7 +32,7 @@ h5path nxentry =
     image ∷ H5Path
     image = "scan_data/data_01"
 
-sampleCalibration ∷ XrdZeroDCalibration Xpad32
+sampleCalibration ∷ XrdZeroDCalibration PyFAI
 sampleCalibration = XrdZeroDCalibration (XrdZeroDSample name outputdir entries) Xpad32 LaB6
     where
       name ∷ String
@@ -70,11 +70,11 @@ sampleCalibration = XrdZeroDCalibration (XrdZeroDSample name outputdir entries)
 --          ]
 --        ]
 
--- | Main
+--  Main
 
 schlegel :: IO ()
 schlegel = do
-  -- | pre-calibrate (extract from nexus to edf in order to do the
+  -- pre-calibrate (extract from nexus to edf in order to do the
   -- calibration)
   extractEdf sampleCalibration
 
@@ -93,7 +93,7 @@ schlegel = do
   -- -- read/write and computation
   -- -- integrateMesh (XrdMeshParams poniextref' mflat method) [fly]
 
-  -- -- | set the integration parameters
+  -- --  set the integration parameters
   -- let mflat = Nothing
   -- let aiMethod = Csr
   -- let params = XrdOneDParams poniextref' mflat aiMethod
