@@ -1,7 +1,6 @@
-{-# LANGUAGE CPP #-}
-{-# LANGUAGE GADTs #-}
+{-# LANGUAGE GADTs             #-}
 {-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE UnicodeSyntax #-}
+{-# LANGUAGE UnicodeSyntax     #-}
 
 module Hkl.Xrd.Calibration
        ( NptExt(..)
@@ -11,113 +10,44 @@ module Hkl.Xrd.Calibration
        , extractEdf
        ) where
 
-import Prelude hiding ((<>))
-import Control.Applicative ((<$>), (<*>), pure)
-import Control.Monad.IO.Class (liftIO)
-import Data.Array.Repa.Index (DIM2)
-import Data.ByteString.Char8 (pack)
-import Data.List (foldl')
-import Data.Text (unlines, pack)
-import Data.Vector.Storable
-  ( Vector
-  , head
-  , concat
-  , fromList
-  , slice
-  , toList
-  )
-import Numeric.LinearAlgebra
-  ( Matrix
-  , (<>)
-  , atIndex
-  , ident
-  )
-import Numeric.GSL.Minimization
-  ( MinimizeMethod ( NMSimplex2 )
-  , minimizeV
-  )
-import Numeric.Units.Dimensional.Prelude (meter, radian, nano, (/~), (*~))
-import Pipes.Safe ( MonadSafe
-                  , runSafeT, bracket
-                  )
-import System.Exit ( ExitCode( ExitSuccess ) )
-import System.FilePath.Posix ((</>), takeFileName)
-import Text.Printf ( printf )
+import           Control.Monad.IO.Class            (liftIO)
+import           Data.Array.Repa.Index             (DIM2)
+import           Data.ByteString.Char8             (pack)
+import           Data.List                         (foldl')
+import           Data.Text                         (pack, unlines)
+import           Data.Vector.Storable              (Vector, fromList, slice,
+                                                    toList)
+import           Numeric.GSL.Minimization          (MinimizeMethod (NMSimplex2),
+                                                    minimizeV)
+import           Numeric.LinearAlgebra             (Matrix, atIndex, ident,
+                                                    ( #> ), (<>))
+import           Numeric.Units.Dimensional.Prelude (meter, nano, radian, (*~),
+                                                    (/~))
+import           Pipes.Safe                        (MonadSafe, bracket,
+                                                    runSafeT)
+import           System.Exit                       (ExitCode (ExitSuccess))
+import           System.FilePath.Posix             (takeFileName, (</>))
+import           Text.Printf                       (printf)
 
--- import Hkl.C ( Geometry ( Geometry )
---              , Factory ( K6c )
---              , geometryDetectorRotationGet
---              )
--- import Hkl.DataSource ( DataItem ( DataItemH5 ) )
--- import Hkl.Detector ( Detector ( ZeroD )
---                     , coordinates
---                     )
--- import Hkl.Edf ( ExtractEdf()
---                , extractEdf
---                )
--- import Hkl.H5 ( Dataset, File, H5
---               , closeDataset
---               , get_position
---               , openDataset
---               , withH5File
---               )
--- import Hkl.PyFAI ( Calibrant, Npt
---                  , NptEntry ( NptEntry )
---                  , Poni
---                  , PoniExt ( PoniExt )
---                  , Pose ( Pose )
---                  , fromAxisAndAngle
---                  , nptEntries
---                  , nptFromFile
---                  , nptWavelength
---                  , poniEntryFromList
---                  , poniEntryToList
---                  , toPyFAICalibArg
---                  )
--- import Hkl.Python ( toPyVal )
--- import Hkl.MyMatrix ( Basis ( HklB, PyFAIB )
---                     , MyMatrix ( MyMatrix )
---                     , changeBase
---                     )
--- import Hkl.Nxs ( DataFrameH5Path ( XrdOneDH5Path )
---                , Nxs ( Nxs )
---                )
--- import Hkl.Script ( Py2, Sh
---                   , Script ( Py2Script, ScriptSh )
---                   , run
---                   , scriptSave
---                   )
--- import Hkl.Types ( AbsDirPath, SampleName
---                  , Source ( Source )
---                  , WaveLength )
--- import Hkl.Xrd.OneD ( XrdOneD
---                     , getPoseEdf
---                     )
+import           Prelude                           hiding ((<>))
 
-import Hkl.C
-import Hkl.DataSource
-import Hkl.Detector
-import Hkl.Edf
-import Hkl.H5
-import Hkl.PyFAI
-import Hkl.Python
-import Hkl.MyMatrix
-import Hkl.Nxs
-import Hkl.Script
-import Hkl.Types
-import Hkl.Xrd.OneD
+import           Hkl.C
+import           Hkl.DataSource
+import           Hkl.Detector
+import           Hkl.Edf
+import           Hkl.H5
+import           Hkl.MyMatrix
+import           Hkl.Nxs
+import           Hkl.PyFAI
+import           Hkl.Python
+import           Hkl.Script
+import           Hkl.Types
+import           Hkl.Xrd.OneD
 
-#if !MIN_VERSION_hmatrix(0, 17, 0)
-(#>) :: Matrix Double -> Vector Double -> Vector Double
-(#>) = (<>)
-#else
-import Numeric.LinearAlgebra ((#>))
-#endif
+--  Calibration
 
--- | Calibration
-
-data NptExt a = NptExt { nptExtNpt :: Npt
-                       , nptExtPose :: Pose
+data NptExt a = NptExt { nptExtNpt      :: Npt
+                       , nptExtPose     :: Pose
                        , nptExtDetector :: Detector a DIM2
                        }
               deriving (Show)
@@ -160,8 +90,8 @@ getPoseNxs f (XrdOneDH5Path _ g d w) i' = runSafeT $
       gamma <- get_position g' 0
       delta <- get_position d' i'
       wavelength <- get_position w' 0
-      let source = Source (Data.Vector.Storable.head wavelength *~ nano meter)
-      let positions = Data.Vector.Storable.concat [mu, komega, kappa, kphi, gamma, delta]
+      let source = Source (wavelength *~ nano meter)
+      let positions = Data.Vector.Storable.fromList [mu, komega, kappa, kphi, gamma, delta]
       let geometry = Geometry K6c source positions Nothing
       let detector = ZeroD
       m <- geometryDetectorRotationGet geometry detector
@@ -172,7 +102,7 @@ getWavelength ∷ File → DataFrameH5Path XrdOneD → IO WaveLength
 getWavelength f (XrdOneDH5Path _ _ _ w) = runSafeT $
     withDataItem f w $ \w' -> liftIO $ do
       wavelength <- get_position w' 0
-      return $ Data.Vector.Storable.head wavelength *~ nano meter
+      return $ wavelength *~ nano meter
 
 readWavelength :: XRDCalibrationEntry -> IO WaveLength
 readWavelength e =
@@ -196,7 +126,7 @@ readXRDCalibrationEntry d e@(XRDCalibrationEntryEdf _ _) =
   <*> getPoseEdf (xrdCalibrationEntryEdf'Edf e)
   <*> pure d
 
--- | Poni Calibration
+--  Poni Calibration
 
 -- The minimized function is the quadratic difference of the
 -- theoretical tth angle and for each pixel, the computed tth angle.
@@ -291,7 +221,7 @@ calibrate (XRDCalibration _ _ d _ es) p = do
   print _p
   return $ fromGsl p solution
 
--- | Edf extraction before calibration
+--  Edf extraction before calibration
 
 edf ∷ AbsDirPath → FilePath → Int → FilePath
 edf o n i = o </> f
