@@ -47,7 +47,7 @@ import Hkl.Types
 import Hkl.Utils
 import Hkl.Xrd.OneD
 
--- | Types
+--  Types
 
 data XrdMeshSource  = XrdMeshSourceNxs (Nxs XrdMesh)
                     | XrdMeshSourceNxsFly [Nxs XrdMesh]
@@ -55,7 +55,7 @@ data XrdMeshSource  = XrdMeshSourceNxs (Nxs XrdMesh)
 
 data XrdMesh' = XrdMesh DIM1 DIM1 (Maybe Threshold) XrdMeshSource deriving (Show)
 
-data XrdMeshSample = XrdMeshSample SampleName AbsDirPath [XrdMesh'] deriving (Show) -- ^ nxss
+data XrdMeshSample = XrdMeshSample SampleName AbsDirPath [XrdMesh'] deriving (Show) --  nxss
 
 data XrdMeshParams a = XrdMeshParams PoniExt (Maybe (Flat a)) AIMethod
 
